#!/bin/bash
#
# Author: Carsten Schoene <carsten.schoene@internetx.de>
# $LastChangedDate: 2011-09-07 21:55:21 +0200 (Wed, 07 Sep 2011) $
# $Rev: 1081 $
# configuration
#
# uncomment to activate bash debugging output
#set -x

ALERTADDRESS="support@internetx.de"
BACKUPHOST="85.236.36.10"

[ -r /etc/ix-pleskbackup.conf ] && . /etc/ix-pleskbackup.conf

if [ "${DISABLE_BACKUP}" == "yes" ] ; then
	exit 0
fi
# check if a process is running
if [ -f /var/lock/plesk_backup_cron ] ; then
	exit 1
else
	if [ ! -d /var/lock ]; then
		mkdir -p /var/lock
	fi
	touch /var/lock/plesk_backup_cron
fi


function get_admin_email {
	if [ "${GET_EMAIL_FROM_DATABASE}" != "no" ] ; then
		if [ -f /etc/psa/.psa.shadow ] ; then    
			ADMINPASS=`cat /etc/psa/.psa.shadow`
		else
			ADMINPASS=""
		fi
		ADMINEMAIL=`mysql -uadmin -p${ADMINPASS} psa -e -ss "SELECT email FROM clients WHERE type='admin' LIMIT 0,1;"`
		if [ -n "${ADMINEMAIL}" ] ; then
			if [ "${ALERTADDRESS}" != "${ADMINEMAIL}" ] ; then
				export ALERTADDRESS=${ADMINEMAIL}
			fi
		fi
	fi
}

if [ "${OVERWRITE_AUTOMATIC_SCHEDULE}" != "yes" ] ; then
# get current hour and minute
HOUR=`date +%H`
MINUTE=`date +%M`
fi

# read first ip address
MYIP=`/sbin/ifconfig | grep -v inet6 | grep inet | grep -v 127.0.0.1 | awk ' {print $2}' | head -n 1 | awk -F: '{print $NF }'`

# get third octed from ip addrss
MYNET=`echo ${MYIP} | awk -F. '{print $3}'`

function email_alert {
	get_admin_email
        if [ -s /var/lock/plesk_backup_cron ]; then
                mail -s "Plesk Backup Error: `hostname -f` - ${MYIP}" ${ALERTADDRESS} < /var/lock/plesk_backup_cron
        fi
}

# read ftp logindata from file
if [ -f /etc/psa/.backup.shadow ] ; then
	# /etc/psa/.backup.shadow
	# FTP_USER="dsXXXXXXXXXX"
	# FTP_PASS="10Se...."
	
	. /etc/psa/.backup.shadow
	
else
	echo "Error: /etc/psa/.backup.shadow not found" >> /var/lock/plesk_backup_cron
	email_alert
	exit 1
fi

function run_backup {
	if [ -z "`/usr/local/psa/bin/pleskbackup --help | grep FTP_PASSWORD`" ]; then
		# old pleskbackup tool
		mkdir -p /var/www
		cd /var/www
		nice -n19 /usr/local/psa/bin/pleskbackup -s 1G all /var/www/psa-full-backup >> /var/lock/plesk_backup_cron
		RETVAL=$?
		ftp -n -i << EOFTP >> /var/lock/plesk_backup_cron 2>&1
open ${BACKUPHOST}
user ${FTP_USER} ${FTP_PASS}
dele psa-full-backup*
mput psa-full-backup*
by
EOFTP
		rm -f /var/www/psa-full-backup*
	else
		if [ -z "`/usr/local/psa/bin/pleskbackup --help |grep '\--output-file'`" ] ; then
			# pre plesk 9
        		nice -n19 /usr/local/psa/bin/pleskbackup -s 1G all ftp://${FTP_USER}:${FTP_PASS}@${BACKUPHOST}/psa-full-backup 2> /var/lock/plesk_backup_cron
			RETVAL=$?
		else
			# plesk 9
			nice -n19 /usr/local/psa/bin/pleskbackup server -s 1G --ftp-login=${FTP_USER} --ftp-password=${FTP_PASS} --output-file=ftp://${BACKUPHOST}/psa-full-backup 2> /var/lock/plesk_backup_cron
			RETVAL=$?
		fi
	fi

	if [ ! ${RETVAL} == 0 ]; then
		email_alert
	else
		date > /root/bin/backup.lastrun
	fi
}

if [ "$1" == "--forcenow" ] ; then
	
	run_backup

else

# time definitions

if [ ${MYNET} == 32 ] && [ ${HOUR} == 21 ] && [ ${MINUTE} == 00 ]; then

	run_backup

elif [ ${MYNET} == 33 ] && [ ${HOUR} == 21 ] && [ ${MINUTE} == 30 ]; then

	run_backup

elif [ ${MYNET} == 34 ] && [ ${HOUR} == 22 ] && [ ${MINUTE} == 00 ]; then

	run_backup

elif [ ${MYNET} == 35 ] && [ ${HOUR} == 22 ] && [ ${MINUTE} == 30 ]; then

	run_backup

elif [ ${MYNET} == 36 ] && [ ${HOUR} == 23 ] && [ ${MINUTE} == 00 ]; then

	run_backup

elif [ ${MYNET} == 37 ] && [ ${HOUR} == 23 ] && [ ${MINUTE} == 30 ]; then

	run_backup

elif [ ${MYNET} == 38 ] && [ ${HOUR} == 00 ] && [ ${MINUTE} == 00 ]; then

	run_backup

elif [ ${MYNET} == 39 ] && [ ${HOUR} == 00 ] && [ ${MINUTE} == 30 ]; then

	run_backup

elif [ ${MYNET} == 40 ] && [ ${HOUR} == 01 ] && [ ${MINUTE} == 00 ]; then

	run_backup

elif [ ${MYNET} == 41 ] && [ ${HOUR} == 01 ] && [ ${MINUTE} == 30 ]; then

	run_backup

elif [ ${MYNET} == 42 ] && [ ${HOUR} == 02 ] && [ ${MINUTE} == 00 ]; then

	run_backup

elif [ ${MYNET} == 43 ] && [ ${HOUR} == 02 ] && [ ${MINUTE} == 30 ]; then

	run_backup

elif [ ${MYNET} == 44 ] && [ ${HOUR} == 03 ] && [ ${MINUTE} == 00 ]; then

	run_backup

elif [ ${MYNET} == 45 ] && [ ${HOUR} == 03 ] && [ ${MINUTE} == 30 ]; then

	run_backup

elif [ ${MYNET} == 46 ] && [ ${HOUR} == 04 ] && [ ${MINUTE} == 00 ]; then

	run_backup

elif [ ${MYNET} == 47 ] && [ ${HOUR} == 04 ] && [ ${MINUTE} == 30 ]; then

	run_backup

elif [ ${MYNET} == 48 ] && [ ${HOUR} == 05 ] && [ ${MINUTE} == 00 ]; then

	run_backup

elif [ ${MYNET} == 49 ] && [ ${HOUR} == 05 ] && [ ${MINUTE} == 30 ]; then

	run_backup

elif [ ${MYNET} == 50 ] && [ ${HOUR} == 06 ] && [ ${MINUTE} == 00 ]; then

	run_backup

elif [ ${MYNET} == 51 ] && [ ${HOUR} == 06 ] && [ ${MINUTE} == 30 ]; then

	run_backup

elif [ ${MYNET} == 52 ] && [ ${HOUR} == 07 ] && [ ${MINUTE} == 00 ]; then

	run_backup

elif [ ${MYNET} == 53 ] && [ ${HOUR} == 07 ] && [ ${MINUTE} == 30 ]; then

	run_backup

elif [ ${MYNET} == 54 ] && [ ${HOUR} == 08 ] && [ ${MINUTE} == 00 ]; then

	run_backup

elif [ ${MYNET} == 55 ] && [ ${HOUR} == 08 ] && [ ${MINUTE} == 30 ]; then

	run_backup

elif [ ${MYNET} == 56 ] && [ ${HOUR} == 09 ] && [ ${MINUTE} == 00 ]; then

	run_backup

elif [ ${MYNET} == 57 ] && [ ${HOUR} == 09 ] && [ ${MINUTE} == 30 ]; then

	run_backup

elif [ ${MYNET} == 58 ] && [ ${HOUR} == 10 ] && [ ${MINUTE} == 00 ]; then

	run_backup

elif [ ${MYNET} == 59 ] && [ ${HOUR} == 10 ] && [ ${MINUTE} == 30 ]; then

	run_backup

elif [ ${MYNET} == 60 ] && [ ${HOUR} == 11 ] && [ ${MINUTE} == 00 ]; then

	run_backup

elif [ ${MYNET} == 61 ] && [ ${HOUR} == 11 ] && [ ${MINUTE} == 30 ]; then

	run_backup

elif [ ${MYNET} == 62 ] && [ ${HOUR} == 12 ] && [ ${MINUTE} == 00 ]; then

	run_backup

elif [ ${MYNET} == 63 ] && [ ${HOUR} == 12 ] && [ ${MINUTE} == 30 ]; then

	run_backup

elif [ ${HOUR} == 13 ] && [ ${MINUTE} == 00 ] && [ -n "`echo ${MYIP} | grep -E '(^62.116)'`" ]; then

	run_backup
	
fi


fi # end --forcenow

rm -f /var/lock/plesk_backup_cron
